#!/usr/bin/env python

from distutils.core import setup
import os

setup(name='touchsearch-googlemapsmobile',
   version='1.0',
   data_files = [
      ('/opt/touchsearch/search_engines/GoogleMapsMobile/',['GoogleMapsMobile.search', 'google_maps_mobile_color.png', 'google_maps_mobile_ghosted.png'])
      ]
      )